@@ -3,7 +3,7 @@ import re
 from helga.plugins import match
 
 
-@match(r'^s/(.*?)/(.*?)/?$')
+@match(r'^s/(.*?)/(.*?)(/.*?)?$')
 def meant_to_say(client, channel, nick, message, matches):
     """
     A plugin so users can correct what they have said. For example::
@@ -17,8 +17,17 @@ def meant_to_say(client, channel, nick, message, matches):
     except KeyError:
         return None
 
-    old, new = matches[0]
-    modified = re.sub(old, new, last)
+    old, new, reflags = matches[0]
+    count = 1
+
+    if re.search('g', reflags, re.I):
+        count = 0
+    if re.search('i', reflags, re.I):
+        regex = re.compile(old, re.I)
+    else:
+        regex = re.compile(old)
+
+    modified = regex.sub(new, last, count)
 
     # Don't respond if we don't replace anything ... it's annoying
     if modified != last:
